searchData={"content_type":"text/markdown","items":[{"doc":"A simple implementation of the [JSON-RPC](https://www.jsonrpc.org/specification).\n\nJSON-RPC is a remote procedure call protocol encoded in JSON.\nIt is similar to the XML-RPC protocol, defining only a few data types and commands.\n\nJSON-RPC allows for notifications (data sent to the server that does not require a response)\nand for multiple calls to be sent to the server which may be answered asynchronously.","ref":"PhxJsonRpc.html","title":"PhxJsonRpc","type":"module"},{"doc":"Add `:phx_json_rpc` to your dependencies\n\n```\n{:phx_json_rpc, \"~> 0.6.0\"}\n```","ref":"PhxJsonRpc.html#module-getting-started","title":"Getting started - PhxJsonRpc","type":"module"},{"doc":"1. Prepare your service specification, written as JSON SCHEMA\n\n    The bunch of examples can be found [here](https://github.com/open-rpc/examples).\n\n    Usually it should be stored as a dependency or just a file in your repo (for ex `myapp/priv/static/openrpc.json`).\n\n2. Configure rpc router, specifying json schema version and batch size params\n\n```\ndefmodule MyApp.Rpc.Router do\n  use PhxJsonRpc.Router,\n    otp_app: :rpc_router,\n    schema: \"[PATH_TO_YOUR_SCHEMA]\",\n    version: \"2.0\",\n    max_batch_size: 20\n\n  alias MyAppRpc.PetController","ref":"PhxJsonRpc.html#module-usage-with-phoenix","title":"Usage with phoenix - PhxJsonRpc","type":"module"},{"doc":"# Uncomment the line below, when neccessary (see `PhxJsonRpc.Router.Middleware` for usage)\n  # middleware([AuthMiddleware])","ref":"PhxJsonRpc.html#module-middleware-group-optional","title":"Middleware group (optional) - PhxJsonRpc","type":"module"},{"doc":"rpc(\"pet.create\", PetController, :create, \"#/components/schemas/Pet\")\n  rpc(\"pet.list\", PetController, :list, \"#/components/schemas/Pets\")\n  rpc(\"pet.update\", PetController, :update, \"#/components/schemas/Pet\")\n  rpc(\"pet.delete\", PetController, :delete, \"#/components/schemas/PetId\")\nend\n```\n\n3. Specify service module\n\n```\ndefmodule MyAppRpc.PetController do\n  @moduledoc \"My Pet Service\"\n\n  def create(%{\"name\" => name}, context) do\n    \"Created\"\n  end\n\n  def list(_params, context) do\n    [\n      \"Cat\",\n      \"Dog\"\n    ]\n  end\n\n  def update(params, context) do\n    \"Update your pet here\"\n  end\n\n  def delete(%{\"id\" => id}, context) do\n    \"Pet removed from the store\"\n  end\nend\n```\n\n4. Create controller for handling requests via http\n\n```\ndefmodule MyAppWeb.RpcController do\n  use MyAppWeb, :controller\n\n  alias MyApp.Rpc.Router\n\n  def rpc(conn, request) do\n    # Handles rpc requests\n    # The second parameter is optional and used to share current context\n    response = Router.handle(request, conn)\n    render(conn, \"response.json\", response)\n  end\nend\n```\n\n5. Import helpers inside your view and define render function\n\n```\ndefmodule MyAppWeb.RpcView do\n  use MyAppWeb, :view\n\n  import PhxJsonRpc.Views.Helpers\n\n  def render(\"response.json\", %{response: response}) do\n    render_json(response)\n  end\nend\n```\n\nOptionally, you can `import PhxJsonRpc.Views.Helpers` inside the `view_helpers` quote block in your `web.ex` like so:\n\n```\n  defp view_helpers do\n    quote do\n      ...\n\n      import PhxJsonRpcWeb.Views.Helpers\n    end\n  end\n```\n\n6. Add endpoint path to your phoenix router under the `api` scope\n\n```\nscope \"/api\", MyAppWeb do\n  pipe_through :api\n\n  post(\"/rpc\", RpcController, :rpc)\nend\n```\n\n7. Start phoenix server and make an http request\n\n```\ncurl -X POST    -H 'Content-Type:application/json'    -d '{\"jsonrpc\":\"2.0\",\"id\":\"[ID]\",\"method\":\"pet.create\",\"params\":{\"name\":\"Kitty\"}}'    http://localhost:4000/api/rpc\n```\n\nRequest and response using postman:\n\n![request](test/priv/static/assets/request.png \"request\")\n\n![response](test/priv/static/assets/response.png \"response\")","ref":"PhxJsonRpc.html#module-pet-s-service","title":"Pet's service - PhxJsonRpc","type":"module"},{"doc":"Basic struct for the rpc request.","ref":"PhxJsonRpc.Request.html","title":"PhxJsonRpc.Request","type":"module"},{"doc":"Creates the new rpc request from the given params.","ref":"PhxJsonRpc.Request.html#new/1","title":"PhxJsonRpc.Request.new/1","type":"function"},{"doc":"iex> PhxJsonRpc.Request.new(version: \"2.0\", method: \"hello\", params: %{\"name\" => \"John\"}, id: \"[REQUEST-UUID]\")\n    %PhxJsonRpc.Request{\n      version: \"2.0\",\n      method: \"hello\",\n      params: %{\"name\" => \"John\"},\n      id: \"[REQUEST-UUID]\",\n      valid?: nil,\n      error: nil\n    }","ref":"PhxJsonRpc.Request.html#new/1-examples","title":"Examples - PhxJsonRpc.Request.new/1","type":"function"},{"doc":"Type represents structure for the rpc request.","ref":"PhxJsonRpc.Request.html#t:t/0","title":"PhxJsonRpc.Request.t/0","type":"type"},{"doc":"Basic struct for the rpc response","ref":"PhxJsonRpc.Response.html","title":"PhxJsonRpc.Response","type":"module"},{"doc":"Creates an empty rpc response.","ref":"PhxJsonRpc.Response.html#empty/1","title":"PhxJsonRpc.Response.empty/1","type":"function"},{"doc":"iex> PhxJsonRpc.Response.empty()\n    %PhxJsonRpc.Response{\n      version: nil,\n      data: nil,\n      id: nil,\n      valid?: false,\n      error: nil\n    }","ref":"PhxJsonRpc.Response.html#empty/1-examples","title":"Examples - PhxJsonRpc.Response.empty/1","type":"function"},{"doc":"Creates the new rpc response from the given params.","ref":"PhxJsonRpc.Response.html#new/1","title":"PhxJsonRpc.Response.new/1","type":"function"},{"doc":"iex> PhxJsonRpc.Response.new(version: \"2.0\", data: \"hello\", id: \"[REQUEST-UUID]\", valid?: true)\n    %PhxJsonRpc.Response{\n      version: \"2.0\",\n      data: \"hello\",\n      id: \"[REQUEST-UUID]\",\n      valid?: true,\n      error: nil\n    }","ref":"PhxJsonRpc.Response.html#new/1-examples","title":"Examples - PhxJsonRpc.Response.new/1","type":"function"},{"doc":"Type represents structure for the rpc response.","ref":"PhxJsonRpc.Response.html#t:t/0","title":"PhxJsonRpc.Response.t/0","type":"type"},{"doc":"MetaData struct for the paths, defined in rpc router.\n\nContains information about called controllers, actions and schema references for the given rpc method.","ref":"PhxJsonRpc.Router.MetaData.html","title":"PhxJsonRpc.Router.MetaData","type":"module"},{"doc":"Creates the new metadata from the given params.","ref":"PhxJsonRpc.Router.MetaData.html#new/1","title":"PhxJsonRpc.Router.MetaData.new/1","type":"function"},{"doc":"iex> PhxJsonRpc.Router.MetaData.new(controller: RpcController, action: :hello, schema_ref: \"#/components/schema/hello\")\n    %PhxJsonRpc.Router.MetaData{\n      controller: RpcController,\n      action: :hello,\n      schema_ref: \"#/components/schema/hello\"\n    }","ref":"PhxJsonRpc.Router.MetaData.html#new/1-examples","title":"Examples - PhxJsonRpc.Router.MetaData.new/1","type":"function"},{"doc":"Type represents structure for the rpc metadata.","ref":"PhxJsonRpc.Router.MetaData.html#t:t/0","title":"PhxJsonRpc.Router.MetaData.t/0","type":"type"},{"doc":"Type definitions for the rpc requests, responses and errors.","ref":"PhxJsonRpc.Types.html","title":"PhxJsonRpc.Types","type":"module"},{"doc":"Parses parameters, applying them to the given struct, falling back to defaults for the rest.","ref":"PhxJsonRpc.Types.html#parse_params/2","title":"PhxJsonRpc.Types.parse_params/2","type":"function"},{"doc":"Type represents jsonrpc version number.","ref":"PhxJsonRpc.Types.html#t:jsonrpc_version/0","title":"PhxJsonRpc.Types.jsonrpc_version/0","type":"type"},{"doc":"Type represents possible rpc errors.","ref":"PhxJsonRpc.Types.html#t:rpc_error/0","title":"PhxJsonRpc.Types.rpc_error/0","type":"type"},{"doc":"Type represents rpc request ID. Whether it's nil, string or number.","ref":"PhxJsonRpc.Types.html#t:rpc_request_id/0","title":"PhxJsonRpc.Types.rpc_request_id/0","type":"type"},{"doc":"Type represents called rpc request method in the form of string.","ref":"PhxJsonRpc.Types.html#t:rpc_request_method/0","title":"PhxJsonRpc.Types.rpc_request_method/0","type":"type"},{"doc":"Type represents rpc request parameters. In terms of elixir, it's a list or a map.","ref":"PhxJsonRpc.Types.html#t:rpc_request_params/0","title":"PhxJsonRpc.Types.rpc_request_params/0","type":"type"},{"doc":"Type represents rpc response.","ref":"PhxJsonRpc.Types.html#t:rpc_response/0","title":"PhxJsonRpc.Types.rpc_response/0","type":"type"},{"doc":"The entrypoint for defining rpc routes.","ref":"PhxJsonRpc.Router.html","title":"PhxJsonRpc.Router","type":"module"},{"doc":"* `otp_app` - name of the OTP application.\n\n  * `schema` - specifies path to your json-schema file.\n\n  * `version` - jsonrpc version.\n\n  * `max_batch_size` - maximum number of requests per batch.\n\n#","ref":"PhxJsonRpc.Router.html#module-config","title":"Config - PhxJsonRpc.Router","type":"module"},{"doc":"defmodule MyRpcRouter do\n      use PhxJsonRpc.Router,\n        otp_app: :rpc_router,\n        schema: \"[PATH_TO_OPENRPC_SCHEMA]\",\n        version: \"2.0\",\n        max_batch_size: 20\n\n      rpc(\"greet\", HelloController, :hello)\n    end","ref":"PhxJsonRpc.Router.html#module-example","title":"Example - PhxJsonRpc.Router","type":"module"},{"doc":"You can override pipeline for handling requests, by adding extra-params in `config` file.\n\nAll the options should implement specific behaviour.\n\nIf option is not present in the config, it will be setted to the package defaults.\n\n* `parser` - should implement `PhxJsonRpc.Router.Parser`\n\n* `validator` - should implement `PhxJsonRpc.Router.Validator`\n\n* `dispatcher` - should implement `PhxJsonRpc.Router.Dispatcher`\n\n#","ref":"PhxJsonRpc.Router.html#module-otp-customization-optional","title":"OTP customization (optional) - PhxJsonRpc.Router","type":"module"},{"doc":"```\n  config :rpc_router, MyRpcRouter,\n    parser: MyRpc.Parser,\n    validator: MyRpc.Validator,\n    dispatcher: MyRpc.Dispatcher\n```","ref":"PhxJsonRpc.Router.html#module-example","title":"Example - PhxJsonRpc.Router","type":"module"},{"doc":"Keeps user-defined middleware.","ref":"PhxJsonRpc.Router.html#middleware/1","title":"PhxJsonRpc.Router.middleware/1","type":"macro"},{"doc":"* `middleware_group` - enumeration of the list of middleware modules.","ref":"PhxJsonRpc.Router.html#middleware/1-arguments","title":"Arguments - PhxJsonRpc.Router.middleware/1","type":"macro"},{"doc":"middleware(MyMiddlewareOne, MyMiddlewareTwo)","ref":"PhxJsonRpc.Router.html#middleware/1-examples","title":"Examples - PhxJsonRpc.Router.middleware/1","type":"macro"},{"doc":"Generates rpc route match based on the open-rpc schema parameters.","ref":"PhxJsonRpc.Router.html#rpc/4","title":"PhxJsonRpc.Router.rpc/4","type":"macro"},{"doc":"* `method` - the name of the calling method.\n\n  * `controller` - resolving module, often a controller.\n\n  * `action` - resolving function in controller.\n\n  * `schema_ref` - reference inside json schema, used for request params validation (optional).","ref":"PhxJsonRpc.Router.html#rpc/4-arguments","title":"Arguments - PhxJsonRpc.Router.rpc/4","type":"macro"},{"doc":"rpc(\"hello\", HelloController, :hello)\n    rpc(\"pet_create\", PetController, :create, \"#/components/schemas/NewPet\")","ref":"PhxJsonRpc.Router.html#rpc/4-examples","title":"Examples - PhxJsonRpc.Router.rpc/4","type":"macro"},{"doc":"Context that provides access to the stored route list, jsonrpc version and schema.","ref":"PhxJsonRpc.Router.Context.html","title":"PhxJsonRpc.Router.Context","type":"behaviour"},{"doc":"Builds new context.","ref":"PhxJsonRpc.Router.Context.html#build/2","title":"PhxJsonRpc.Router.Context.build/2","type":"function"},{"doc":"iex> PhxJsonRpc.Router.Context.build(Context, %{\"is_rpc\" => true})\n    %PhxJsonRpc.Router.Context{\n      instance: Context,\n      meta_data: %{\"is_rpc\" => true}\n    }","ref":"PhxJsonRpc.Router.Context.html#build/2-examples","title":"Examples - PhxJsonRpc.Router.Context.build/2","type":"function"},{"doc":"Returns the pre-resolved json-schema.","ref":"PhxJsonRpc.Router.Context.html#c:get_json_schema/0","title":"PhxJsonRpc.Router.Context.get_json_schema/0","type":"callback"},{"doc":"Returns maximum size of the batch.","ref":"PhxJsonRpc.Router.Context.html#c:get_max_batch_size/0","title":"PhxJsonRpc.Router.Context.get_max_batch_size/0","type":"callback"},{"doc":"Returns the middleware group.","ref":"PhxJsonRpc.Router.Context.html#c:get_middleware/0","title":"PhxJsonRpc.Router.Context.get_middleware/0","type":"callback"},{"doc":"Returns the otp application name.","ref":"PhxJsonRpc.Router.Context.html#c:get_otp_app/0","title":"PhxJsonRpc.Router.Context.get_otp_app/0","type":"callback"},{"doc":"Returns the pre-defined list of routes.","ref":"PhxJsonRpc.Router.Context.html#c:get_routes/0","title":"PhxJsonRpc.Router.Context.get_routes/0","type":"callback"},{"doc":"Returns the json rpc version number.","ref":"PhxJsonRpc.Router.Context.html#c:get_version/0","title":"PhxJsonRpc.Router.Context.get_version/0","type":"callback"},{"doc":"Type represents the list of user-defined middleware.","ref":"PhxJsonRpc.Router.Context.html#t:middleware_list/0","title":"PhxJsonRpc.Router.Context.middleware_list/0","type":"type"},{"doc":"Type represents the list of available routes.","ref":"PhxJsonRpc.Router.Context.html#t:route_list/0","title":"PhxJsonRpc.Router.Context.route_list/0","type":"type"},{"doc":"Type represents structure for the rpc context.\n- :instance is typically the self-link\n- :meta_data, if present, is a map, containing user-defined params","ref":"PhxJsonRpc.Router.Context.html#t:t/0","title":"PhxJsonRpc.Router.Context.t/0","type":"type"},{"doc":"Behaviour for the rpc requests dispatcher.","ref":"PhxJsonRpc.Router.Dispatcher.html","title":"PhxJsonRpc.Router.Dispatcher","type":"behaviour"},{"doc":"Dispatches the given rpc request, using module and action definitions in metadata.\n\nIf no metadata specified, falls to `method not found` response.","ref":"PhxJsonRpc.Router.Dispatcher.html#c:dispatch/3","title":"PhxJsonRpc.Router.Dispatcher.dispatch/3","type":"callback"},{"doc":"Middleware interface for the group of routes.\n\nRequest must have `:valid => true` for passing through the next middleware.\n\n#","ref":"PhxJsonRpc.Router.Middleware.html","title":"PhxJsonRpc.Router.Middleware","type":"behaviour"},{"doc":"defmodule AuthMiddleware do\n      use PhxJsonRpc.Router.Middleware\n\n      @impl true\n      def handle(request, context) do\n        if context.meta_data.is_authenticated\n          request\n        else\n          request\n          |> Map.put(:valid?, false)\n          |> Map.put(:error, %AuthError{})\n        end\n      end\n    end\n\n    defmodule AuthError do\n      use PhxJsonRpc.Error,\n        message: \"Unauthenticated\",\n        code: -32_000\n    end","ref":"PhxJsonRpc.Router.Middleware.html#module-example","title":"Example - PhxJsonRpc.Router.Middleware","type":"behaviour"},{"doc":"Handles request before it will be dispatched to the controller.","ref":"PhxJsonRpc.Router.Middleware.html#c:handle/2","title":"PhxJsonRpc.Router.Middleware.handle/2","type":"callback"},{"doc":"Parse behaviour for the rpc requests.","ref":"PhxJsonRpc.Router.Parser.html","title":"PhxJsonRpc.Router.Parser","type":"behaviour"},{"doc":"Parses request, checking it's version, method and parameters.\n\nIf parse fails, returns request with `%PhxJsonRpc.Error.ParseError{}` struct and set `valid?` parameter to false.","ref":"PhxJsonRpc.Router.Parser.html#c:parse/2","title":"PhxJsonRpc.Router.Parser.parse/2","type":"callback"},{"doc":"Behaviour for handling requests via rpc.","ref":"PhxJsonRpc.Router.Pipe.html","title":"PhxJsonRpc.Router.Pipe","type":"behaviour"},{"doc":"Handles rpc requests via the given context(router).\n\nProcesses each request by the following pipeline:\n```\n- parse\n- validate\n- dispatch\n```\n\nIf batch size exceeded, an exception will be rendered and\nrequests for the current batch wont be processed.","ref":"PhxJsonRpc.Router.Pipe.html#c:handle/2","title":"PhxJsonRpc.Router.Pipe.handle/2","type":"callback"},{"doc":"Module for resolving open rpc schema.","ref":"PhxJsonRpc.Router.SchemaResolver.html","title":"PhxJsonRpc.Router.SchemaResolver","type":"module"},{"doc":"Resolves json schema by path.","ref":"PhxJsonRpc.Router.SchemaResolver.html#resolve/1","title":"PhxJsonRpc.Router.SchemaResolver.resolve/1","type":"function"},{"doc":"Validation behaviour for the rpc requests.","ref":"PhxJsonRpc.Router.Validator.html","title":"PhxJsonRpc.Router.Validator","type":"behaviour"},{"doc":"Validates the given rpc request against json-schema provided.\n\nIf validation fails, enriches request with `error` struct and set `valid?` parameter to false.","ref":"PhxJsonRpc.Router.Validator.html#c:validate/3","title":"PhxJsonRpc.Router.Validator.validate/3","type":"callback"},{"doc":"Helper module provides a set of `render` functions for the phoenix views.","ref":"PhxJsonRpcWeb.Views.Helpers.html","title":"PhxJsonRpcWeb.Views.Helpers","type":"module"},{"doc":"Renders json rpc responses.","ref":"PhxJsonRpcWeb.Views.Helpers.html#render_json/1","title":"PhxJsonRpcWeb.Views.Helpers.render_json/1","type":"function"},{"doc":"iex> PhxJsonRpcWeb.Views.Helpers.render_json([\n    ...>%PhxJsonRpc.Response{version: \"2.0\", id: \"ID1\", data: %{name: \"Ron\"}, valid?: true},\n    ...>%PhxJsonRpc.Response{version: \"2.0\", id: \"ID2\", error: %PhxJsonRpc.Error.ServerError{\n    ...>code: -32000, message: \"Server error\"}, valid?: false}])\n    [\n      %{\"id\" => \"ID1\", \"jsonrpc\" => \"2.0\", \"result\" => %{name: \"Ron\"}},\n      %{\"error\" => %{\n        \"code\" => -32000,\n        \"data\" => nil,\n        \"message\" => \"Server error\"\n        },\n        \"id\" => \"ID2\",\n        \"jsonrpc\" => \"2.0\"\n      }\n    ]\n\n    iex> PhxJsonRpcWeb.Views.Helpers.render_json(\n    ...>%PhxJsonRpc.Response{\n    ...>version: \"2.0\",\n    ...>id: \"ID\",\n    ...>data: %{name: \"Ron\"},\n    ...>valid?: true}\n    ...>)\n    %{\"id\" => \"ID\", \"jsonrpc\" => \"2.0\", \"result\" => %{name: \"Ron\"}}","ref":"PhxJsonRpcWeb.Views.Helpers.html#render_json/1-examples","title":"Examples - PhxJsonRpcWeb.Views.Helpers.render_json/1","type":"function"},{"doc":"An abstract json rpc error.","ref":"PhxJsonRpc.Error.html","title":"PhxJsonRpc.Error","type":"module"},{"doc":"Internal JSON-RPC error.","ref":"PhxJsonRpc.Error.InternalError.html","title":"PhxJsonRpc.Error.InternalError","type":"exception"},{"doc":"Type that represents error struct with :code and :message required.","ref":"PhxJsonRpc.Error.InternalError.html#t:t/0","title":"PhxJsonRpc.Error.InternalError.t/0","type":"type"},{"doc":"Invalid method parameter(s).","ref":"PhxJsonRpc.Error.InvalidParams.html","title":"PhxJsonRpc.Error.InvalidParams","type":"exception"},{"doc":"Type that represents error struct with :code and :message required.","ref":"PhxJsonRpc.Error.InvalidParams.html#t:t/0","title":"PhxJsonRpc.Error.InvalidParams.t/0","type":"type"},{"doc":"The JSON sent is not a valid Request object.","ref":"PhxJsonRpc.Error.InvalidRequest.html","title":"PhxJsonRpc.Error.InvalidRequest","type":"exception"},{"doc":"Type that represents error struct with :code and :message required.","ref":"PhxJsonRpc.Error.InvalidRequest.html#t:t/0","title":"PhxJsonRpc.Error.InvalidRequest.t/0","type":"type"},{"doc":"The method does not exist / is not available.","ref":"PhxJsonRpc.Error.MethodNotFound.html","title":"PhxJsonRpc.Error.MethodNotFound","type":"exception"},{"doc":"Type that represents error struct with :code and :message required.","ref":"PhxJsonRpc.Error.MethodNotFound.html#t:t/0","title":"PhxJsonRpc.Error.MethodNotFound.t/0","type":"type"},{"doc":"An error occurred on the server while parsing the JSON text.","ref":"PhxJsonRpc.Error.ParseError.html","title":"PhxJsonRpc.Error.ParseError","type":"exception"},{"doc":"Type that represents error struct with :code and :message required.","ref":"PhxJsonRpc.Error.ParseError.html#t:t/0","title":"PhxJsonRpc.Error.ParseError.t/0","type":"type"},{"doc":"Reserved for implementation-defined server-errors.","ref":"PhxJsonRpc.Error.ServerError.html","title":"PhxJsonRpc.Error.ServerError","type":"exception"},{"doc":"Type that represents error struct with :code and :message required.","ref":"PhxJsonRpc.Error.ServerError.html#t:t/0","title":"PhxJsonRpc.Error.ServerError.t/0","type":"type"},{"doc":"# PhxJsonRpc\n\n![ci.yml][link-ci]\n[![hex.pm badge][link-shield]][link-hex]\n\nSimple implementation of JSON-RPC server, written in [elixir][link-elixir] and working with [phoenix][link-phoenix].\n\nAllows you to define any number of rpc endpoints, which can be accessed via http protocol.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"The package uses router `macro` for matching RPC calls to your end-user service.\n\nIt uses `JSON SCHEMA` as a specification for your services and provides parsing, validation and error handling briefly.\n\nRequests can be served in batches with asyncronous order.\n\nFor usage with phoenix see this [guide][link-guide].","ref":"readme.html#how-it-works","title":"How it works - Overview","type":"extras"},{"doc":"The package can be installed\nby adding `phx_json_rpc` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:phx_json_rpc, \"~> 0.5.0\"}\n  ]\nend\n```\n\nThis package depends on [ex_json_schema](https://github.com/jonasschmidt/ex_json_schema) for validation purposes.","ref":"readme.html#installation","title":"Installation - Overview","type":"extras"},{"doc":"The package tested with `phoenix >= 1.6`, but probably will work with any version started from `1.4`.","ref":"readme.html#supported-phoenix-versions","title":"Supported phoenix versions - Overview","type":"extras"},{"doc":"The docs can be found at [https://hexdocs.pm/phx_json_rpc][link-docs].","ref":"readme.html#documentation","title":"Documentation - Overview","type":"extras"},{"doc":"The package creation was inspired by some other repos:\n\n- [json-rpc-laravel](https://github.com/avto-dev/json-rpc-laravel)\n- [open-rpc](https://github.com/open-rpc/)\n- [phoenix1.4-json-rpc](https://github.com/vruizext/phoenix1.4-json-rpc)","ref":"readme.html#links","title":"Links - Overview","type":"extras"},{"doc":"MIT. Please see the [license file](LICENSE.md) for more information.\n\n[link-ci]: https://github.com/shirokovnv/phx_json_rpc/actions/workflows/ci.yml/badge.svg\n[link-elixir]: https://elixir-lang.org/\n[link-phoenix]: https://www.phoenixframework.org/\n[link-guide]: https://hexdocs.pm/phx_json_rpc/PhxJsonRpc.html\n[link-docs]: https://hexdocs.pm/phx_json_rpc\n[link-shield]: https://img.shields.io/hexpm/v/phx_json_rpc\n[link-hex]: https://hex.pm/packages/phx_json_rpc","ref":"readme.html#license","title":"License - Overview","type":"extras"},{"doc":"# The MIT License (MIT)\r\n\r\nCopyright (c) Nickolai Shirokov  \r\n\r\nPermission is hereby granted, free of charge, to any person obtaining a copy\r\nof this software and associated documentation files (the \"Software\"), to deal\r\nin the Software without restriction, including without limitation the rights\r\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\r\ncopies of the Software, and to permit persons to whom the Software is\r\nfurnished to do so, subject to the following conditions:\r\n\r\nThe above copyright notice and this permission notice shall be included in\r\nall copies or substantial portions of the Software.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\r\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\r\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\r\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\r\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\r\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\r\nTHE SOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"# Changelog\r\n\r\nAll notable changes to `PhxJsonRpc` will be documented in this file.\r\n\r\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\r\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\r\n\r\n## [0.6.0] - 2023-08-30\r\n\r\n#","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- BREAKING CHANGE: Minimum elixir version is set to `1.12`\r\n- Bump ex_json_schema from 0.9.2 to 0.10.1\r\n- Bump dialyxir from 1.3.0 to 1.4.0\r\n- Bump ex_doc from 0.30.3 to 0.30.6\r\n- Bump excoveralls from 0.16.1 to 0.17.1\r\n\r\n## [0.5.0] - 2023-04-21\r\n\r\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- BREAKING CHANGE: `Context` as a second parameter to controller methods\r\n\r\n## [0.4.0] - 2023-04-20\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Middleware interface and macro (handles requests before dispatching to the rpc controller)\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- `Router.handle` now accepts second optional parameter: `meta_data`\r\n- Bump credo from 1.6.7 to 1.7.0\r\n- Bump dialyxir from 1.2.0 to 1.3.0\r\n- Bump excoveralls from 0.15.0 to 0.16.1\r\n- Bump ex_doc from 0.29.0 to 0.29.4\r\n\r\n## [0.3.8] - 2022-11-18\r\n\r\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Bump ex_json_schema from 0.9.1 to 0.9.2\r\n- Bump credo from 1.6.6 to 1.6.7\r\n- Bump ex_doc from 0.28.4 to 0.29.0\r\n- Bump excoveralls from 0.14.6 to 0.15.0\r\n\r\n## [0.3.7] - 2022-08-21\r\n\r\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Example controller moved to the `test` namespace\r\n- Bump dialyxir from `1.1.0` to `1.2.0`\r\n- Bump credo from `1.6.5` to `1.6.6`\r\n\r\n## [0.3.6] - 2022-07-19\r\n\r\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Dialyzer support in `CI`\r\n- Screenshots in `usage with phoenix` guide\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Documentation structure in `README.md`\r\n\r\n## [0.3.5] - 2022-07-18\r\n\r\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Move assets to the test directory\r\n\r\n## [0.3.4] - 2022-07-18\r\n\r\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Example to `howitworks` section in `README.md`\r\n- Specified phoenix version in docs\r\n- Matrix tests in `CI`\r\n- [Dependabot](https://github.com/dependabot) support by [@sobolevn](https://github.com/sobolevn)\r\n- Releases started for github repo\r\n\r\n## [0.3.3] - 2022-07-07\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Follow [Keep a Changelog](https://keepachangelog.com/en/1.0.0/) standart\r\n\r\n## [0.3.2] - 2022-07-06\r\n\r\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- `excoveralls` for test coverage\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Test warnings, some doc typos\r\n\r\n## [0.3.1] - 2022-07-05\r\n\r\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Documentation typo in `PhxJsonRpc.Router`\r\n- Bug with `undefined` error in `PhxJsonRpc.Views.Helpers`\r\n\r\n## [0.3.0] - 2022-07-04\r\n\r\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- OTP configuration for the `PhxJsonRpc.Router`\r\n\r\n## [0.2.2] - 2022-07-03\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- `Request ID` to error log format in `PhxJsonRpc.Router.DefaultDispatcher`\r\n\r\n## [0.2.1] - 2022-07-03\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Improved documentation guide\r\n\r\n#","ref":"changelog.html#updated","title":"Updated - Changelog","type":"extras"},{"doc":"- `howitworks` section to `README.md`\r\n\r\n## [0.2.0] - 2022-07-03\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Maximum batch size limit property for `PhxJsonRpc.Router`\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Typespecs in `PhxJsonRpc.Router.Pipe` section\r\n\r\n## [0.1.1] - 2022-07-03\r\n\r\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Link to `phoenix framework` in `README.md`\r\n\r\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Unneccessary condition, when accessing metadata in `PhxJsonRpc.Router.Pipe`\r\n- Documentation in `PhxJsonRpc.Error` section\r\n\r\n## [0.1.0] - 2022-07-03\r\n\r\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Initial commit","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"}]}